@@ -8,7 +8,7 @@ from .options import FreeFlyLocation, Route32Condition, JohtoOnly, RandomizeBadg
     Route3Access, EliteFourRequirement, Goal, Route44AccessRequirement, BlackthornDarkCaveAccess, RedRequirement, \
     MtSilverRequirement, HMBadgeRequirements, RedGyaradosAccess, EarlyFly, RadioTowerRequirement, \
     BreedingMethodsRequired, Shopsanity, KantoTrainersanity, JohtoTrainersanity, RandomizePokemonRequests, \
-    EnhancedOptionSet
+    EnhancedOptionSet, RandomizeTypes, RandomizeEvolution
 from ..Files import APTokenTypes
 
 if TYPE_CHECKING:
@@ -40,6 +40,7 @@ def __adjust_option_problems(world: "PokemonCrystalWorld"):
     __adjust_options_race_mode(world)
     __adjust_options_pokemon_requests(world)
     __adjust_options_dark_areas(world)
+    __adjust_options_randomize_types(world)
 
 
 def __adjust_options_radio_tower_and_route_44(world: "PokemonCrystalWorld"):
@@ -256,6 +257,15 @@ def __adjust_options_dark_areas(world: "PokemonCrystalWorld"):
         world.options.dark_areas.value = world.options.dark_areas.default
 
 
+def __adjust_options_randomize_types(world: "PokemonCrystalWorld"):
+    if (world.options.randomize_types == RandomizeTypes.option_follow_evolutions and
+            world.options.randomize_evolution == RandomizeEvolution.option_match_a_type):
+        logging.warning(
+            "Pokemon Crystal: Types follow evolutions and evolutions follow types are incompatible. "
+            "Setting Randomize Types to completely random for %s (%s).", world.player, world.player_name)
+        world.options.randomize_types.value = RandomizeTypes.option_completely_random
+
+
 def pokemon_convert_friendly_to_ids(world: "PokemonCrystalWorld", pokemon: Iterable[str]) -> set[str]:
     if not pokemon: return set()
 
