@@ -68,7 +68,6 @@ class PokemonCrystalWorld(World):
     Explore the Johto and Kanto regions, become the Pokémon League Champion, and
     defeat the elusive Red at the peak of Mt. Silver!"""
     game = crystal_data.manifest.game
-    author: str = "James"
     apworld_version = crystal_data.manifest.world_version
 
     topology_present = True
@@ -788,13 +787,13 @@ class PokemonCrystalWorld(World):
                             f"Evolve {self.generated_pokemon[pokemon_id].friendly_name}")
 
         def get_dexsanity_breeding_hint_data(dexsanity_hint_data: dict[str, list[str]]):
-            for pokemon, data in self.generated_pokemon.items():
-                if not can_breed(self, pokemon): continue
+            for parent, data in self.generated_pokemon.items():
+                if not can_breed(self, parent): continue
                 child = data.produces_egg
-                if pokemon == child: continue
-                parent_name = self.generated_pokemon[pokemon].friendly_name
-                if child == "NIDORAN_F" and "NIDORAN_M" in self.generated_dexsanity:
+                parent_name = self.generated_pokemon[parent].friendly_name
+                if child == "NIDORAN_F" and parent != "NIDORAN_M" and "NIDORAN_M" in self.generated_dexsanity:
                     dexsanity_hint_data["NIDORAN_M"].append(f"Breed {parent_name}")
+                if parent == child: continue
                 if child in self.generated_dexsanity:
                     dexsanity_hint_data[child].append(f"Breed {parent_name}")
 
